@@ -55,6 +55,9 @@ DEFAULT_CONFIG = dict(
     # 每个worker的消息队列的最大长度, <=0 代表无限
     TASK_QUEUE_MAX_SIZE=-1,
 
+    # 一次性认领的任务数量最大值，<=0 代表无限
+    TASK_CLAIMED_MAX_SIZE=-1,
+
     # backlog
     BACKLOG=256,
 
